Annotatable class abstract

An element or fragment that can have either annotations (metadata), a documentation comment, or both associated with it.

Annotations
  • @Deprecated('Use Element or Fragment directly instead')

Constructors

Annotatable()

Properties

documentationComment → String?
The content of the documentation comment (including delimiters) for this element or fragment.
no setter
hashCode → int
The hash code for this object.
no setterinherited
metadata → Metadata
The metadata associated with the element or fragment.
no setter
metadata2 → Metadata
The metadata associated with the element or fragment.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited