ElementDirective class abstract

A directive within a library fragment.

Clients may not extend, implement or mix-in this class.

Implemented types

Constructors

ElementDirective()

Properties

documentationComment → String?
The content of the documentation comment (including delimiters) for this element or fragment.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
libraryFragment → LibraryFragment
The library fragment that contains this object.
no setter
metadata → Metadata
The metadata associated with the element or fragment.
no setteroverride
metadata2 → Metadata
The metadata associated with the element or fragment.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → DirectiveUri
The interpretation of the URI specified in the directive.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited