isIgnorable property
Whether a finding of this diagnostic is ignorable via comments such as
// ignore: or // ignore_for_file:.
Implementation
bool get isIgnorable => severity != DiagnosticSeverity.ERROR;
Whether a finding of this diagnostic is ignorable via comments such as
// ignore: or // ignore_for_file:.
bool get isIgnorable => severity != DiagnosticSeverity.ERROR;