PluginBase class abstract

A base class for custom analyzer plugins

If a print is emitted or an exception is uncaught,

Constructors

PluginBase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAssists() → List<Assist>
Obtains the list of assists created by this plugin.
getLintRules(CustomLintConfigs configs) → List<LintRule>
Returns a list of warning/infos/errors for a Dart file.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited